@@ -41,7 +41,7 @@ use constant NUMPY_REGEX => qr/
 
 # Guile object files do not objdump/strip correctly, so exclude them
 # from a number of tests. (#918444)
-use constant GUILE_PATH_REGEX => qr,^usr/lib/[^/]+/[^/]+/guile/[^/]+/.+\.go$,;
+use constant GUILE_PATH_REGEX => qr{^usr/lib(?:/[^/]+)+/guile/[^/]+/.+\.go$};
 
 # These are the ones file(1) looks for.  The ".zdebug_info" being the
 # compressed version of .debug_info.
@@ -135,8 +135,8 @@ our $ARCH_32_REGEX;
 sub installable {
     my ($self) = @_;
 
-    my $pkg = $self->package;
-    my $type = $self->type;
+    my $pkg = $self->processable->name;
+    my $type = $self->processable->type;
     my $processable = $self->processable;
     my $group = $self->group;
 
@@ -153,8 +153,8 @@ sub installable {
     my $has_php_ext = 0;
     my $uses_numpy_c_abi = 0;
 
-    my $arch = $processable->field('architecture', '');
-    my $multiarch = $processable->field('multi-arch', 'no');
+    my $arch = $processable->fields->value('Architecture') // EMPTY;
+    my $multiarch = $processable->fields->value('Multi-Arch') // 'no';
     my $srcpkg = $processable->source;
 
     $arch_hardening = $HARDENING->value($arch)
@@ -162,10 +162,10 @@ sub installable {
 
     my $src = $group->source;
     if (defined($src)) {
-        $built_with_golang = $src->relation('build-depends-all')
+        $built_with_golang = $src->relation('Build-Depends-All')
           ->implies('golang-go | golang-any');
         $built_with_octave
-          = $src->relation('build-depends')->implies('dh-octave');
+          = $src->relation('Build-Depends')->implies('dh-octave');
     } else {
         $built_with_golang = $pkg =~ m/^golang-/;
         $built_with_octave = $pkg =~ m/^octave-/;
@@ -397,8 +397,10 @@ sub installable {
 
         $self->tag('development-package-ships-elf-binary-in-path', $file)
           if exists($PATH_DIRECTORIES{$file->dirname})
-          and $processable->field('section', 'NONE') =~ m/(?:^|\/)libdevel$/
-          and $processable->field('multi-arch', 'NONE') ne 'foreign';
+          and ($processable->fields->value('Section') // 'NONE')
+          =~ m/(?:^|\/)libdevel$/
+          and ($processable->fields->value('Multi-Arch') // 'NONE') ne
+          'foreign';
 
         $objdump = $processable->objdump_info->{$fname};
 
@@ -437,7 +439,7 @@ sub installable {
         }
 
         my $exceptions = {
-            %{ $group->info->spelling_exceptions },
+            %{ $group->spelling_exceptions },
             map { $_ => 1} $BINARY_SPELLING_EXCEPTIONS->all
         };
         my $tag_emitter
