@@ -2,6 +2,7 @@
 #
 # Copyright © 2004 Marc Brockschmidt
 # Copyright © 2020 Chris Lamb <lamby@debian.org>
+# Copyright © 2020 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -31,9 +32,11 @@ use List::Util qw(first none);
 use Path::Tiny;
 
 use Lintian::Data ();
-use Lintian::Deb822Parser qw(parse_dpkg_control_string);
+use Lintian::Deb822::Parser qw(parse_dpkg_control_string);
 use Lintian::Relation ();
 
+use constant EMPTY => q{};
+
 use Moo;
 use namespace::clean;
 
@@ -58,7 +61,7 @@ my $SIGNING_KEY_FILENAMES = Lintian::Data->new('common/signing-key-filenames');
 sub source {
     my ($self) = @_;
 
-    my $pkg = $self->package;
+    my $pkg = $self->processable->name;
     my $processable = $self->processable;
     my $group = $self->group;
 
@@ -76,12 +79,9 @@ sub source {
     return
       unless $dcontrol->is_open_ok;
 
-    # check that control is UTF-8 encoded
-    unless ($dcontrol->is_valid_utf8) {
-
-        $self->tag('debian-control-file-uses-obsolete-national-encoding');
-        return;
-    }
+    # another check complains about invalid encoding
+    return
+      unless $dcontrol->is_valid_utf8;
 
     my $contents = $dcontrol->decoded_utf8;
     my @lines = split(/\n/, $contents);
@@ -111,31 +111,38 @@ sub source {
 
         # line with field:
         if ($line =~ /^(\S+):/) {
-            my $field = lc($1);
-            if ($field =~ /^xs-vcs-/) {
+
+            my $field = $1;
+
+            if ($field =~ /^XS-Vcs-/) {
                 my $base = $field;
-                $base =~ s/^xs-//;
+                $base =~ s/^XS-//;
                 $self->tag('xs-vcs-field-in-debian-control', $field)
                   if $src_fields->known($base);
             }
-            if ($field eq 'xs-testsuite') {
+
+            if ($field eq 'XS-Testsuite') {
                 $self->tag('xs-testsuite-field-in-debian-control', $field);
             }
-            if ($field eq 'xc-package-type') {
+
+            if ($field eq 'XC-Package-Type') {
                 $self->tag('xc-package-type-in-debian-control',
                     "line $position");
             }
+
             unless ($line =~ /^\S+: \S/ || $line =~ /^\S+:$/) {
                 $self->tag('debian-control-has-unusual-field-spacing',
                     "line $position");
             }
+
             # something like "Maintainer: Maintainer: bad field"
             if ($line =~ /^\Q$field\E: \s* \Q$field\E \s* :/xsmi) {
                 $self->tag('debian-control-repeats-field-name-in-value',
                     "line $position");
             }
+
             if (    $field =~ /^Rules?-Requires?-Roots?$/i
-                and $field ne 'rules-requires-root') {
+                and $field ne 'Rules-Requires-Root') {
                 $self->tag('spelling-error-in-rules-requires-root',
                     $field,"(line $position)");
             }
@@ -156,33 +163,36 @@ sub source {
         die "syntax error in debian/control: $@";
     }
 
-    foreach my $field (keys %{$processable->source_field()}) {
+    for my $field ($processable->debian_control->source_fields->names) {
         $self->tag(
             'debian-control-has-empty-field',
             "field \"$field\" in source paragraph",
-        ) if $processable->source_field($field) eq '';
+          )
+          unless
+          length $processable->debian_control->source_fields->value($field);
     }
 
-    my @package_names = $processable->binaries;
+    my @package_names = $processable->debian_control->installables;
 
     foreach my $bin (@package_names) {
-        my $bfields = $processable->binary_field($bin);
+        my $bfields = $processable->debian_control->installable_fields($bin);
         $self->tag('build-info-in-binary-control-file-section', "Package $bin")
           if (
-            first { $bfields->{"build-$_"} }
-            qw(depends depends-indep conflicts conflicts-indep)
+            first { $bfields->value("Build-$_") }
+            qw(Depends Depends-Indep Conflicts Conflicts-Indep)
           );
-        foreach my $field (keys %$bfields) {
+        foreach my $field ($bfields->names) {
             $self->tag(
                 'binary-control-field-duplicates-source',
                 "field \"$field\" in package $bin"
               )
-              if ( $processable->source_field($field)
-                && $bfields->{$field} eq $processable->source_field($field));
+              if ( $processable->debian_control->source_fields->value($field)
+                && $bfields->value($field) eq
+                $processable->debian_control->source_fields->value($field));
             $self->tag(
                 'debian-control-has-empty-field',
                 "field \"$field\" in package $bin",
-            ) if $bfields->{$field} eq '';
+            ) if $bfields->value($field) eq '';
         }
         if ($bin =~ /[-]dbgsym$/) {
             $self->tag('debian-control-has-dbgsym-package', $bin);
@@ -217,10 +227,10 @@ sub source {
     # duplicates, which dpkg-source eliminates.
 
     for my $field (
-        qw(build-depends build-depends-indep
-        build-conflicts build-conflicts-indep)
+        qw(Build-Depends Build-Depends-Indep
+        Build-conflicts Build-Conflicts-Indep)
     ) {
-        my $raw = $processable->source_field($field);
+        my $raw = $processable->debian_control->source_fields->value($field);
         my $rel;
         next unless $raw;
         $rel = Lintian::Relation->new($raw);
@@ -229,10 +239,12 @@ sub source {
 
     for my $bin (@package_names) {
         for my $field (
-            qw(pre-depends depends recommends suggests breaks
-            conflicts provides replaces enhances)
+            qw(Pre-Depends Depends Recommends Suggests Breaks
+            Conflicts Provides Replaces Enhances)
         ) {
-            my $raw = $processable->binary_field($bin, $field);
+            my $raw
+              = $processable->debian_control->installable_fields($bin)
+              ->value($field);
             my $rel;
             next unless $raw;
             $rel = $processable->binary_relation($bin, $field);
@@ -252,10 +264,12 @@ sub source {
     # doesn't hard-code a dependency on libc.  We have to do the
     # latter check here rather than in checks/fields to distinguish
     # from dependencies created by ${shlibs:Depends}.
-    my @dep_fields = qw(pre-depends depends recommends suggests);
+    my @dep_fields = qw(Pre-Depends Depends Recommends Suggests);
     foreach my $bin (@package_names) {
         for my $strong (0 .. $#dep_fields) {
-            next unless $processable->binary_field($bin, $dep_fields[$strong]);
+            next
+              unless $processable->debian_control->installable_fields($bin)
+              ->value($dep_fields[$strong]);
             my $relation
               = $processable->binary_relation($bin, $dep_fields[$strong]);
             $self->tag('package-depends-on-itself', $bin, $dep_fields[$strong])
@@ -266,9 +280,11 @@ sub source {
               and $pkg !~ /^e?glibc$/;
             for my $weak (($strong + 1) .. $#dep_fields) {
                 next
-                  unless $processable->binary_field($bin, $dep_fields[$weak]);
+                  unless $processable->debian_control->installable_fields($bin)
+                  ->value($dep_fields[$weak]);
                 for my $dependency (split /\s*,\s*/,
-                    $processable->binary_field($bin, $dep_fields[$weak])) {
+                    $processable->debian_control->installable_fields($bin)
+                    ->value($dep_fields[$weak])) {
                     next unless $dependency;
                     $self->tag('stronger-dependency-implies-weaker',
                         $bin,"$dep_fields[$strong] -> $dep_fields[$weak]",
@@ -299,25 +315,29 @@ sub source {
     # duplicate the descriptions of non-udeb packages and the package
     # description for udebs is much less important or significant to
     # the user.
-    my $area = $processable->source_field('section');
+    my $area = $processable->debian_control->source_fields->value('Section');
     if (defined $area) {
         if ($area =~ m%^([^/]+)/%) {
             $area = $1;
         } else {
             $area = 'main';
         }
-    } else {
-        $self->tag('no-section-field-for-source');
     }
+
     my @descriptions;
     my ($seen_main, $seen_contrib);
     foreach my $bin (@package_names) {
-        my $depends = $processable->binary_field($bin, 'depends', '');
+        my $depends
+          = $processable->debian_control->installable_fields($bin)
+          ->value('Depends')// EMPTY;
 
         # Accumulate the description.
-        my $desc = $processable->binary_field($bin, 'description');
+        my $desc = $processable->debian_control->installable_fields($bin)
+          ->value('Description');
         my $bin_area;
-        if ($desc and $processable->binary_package_type($bin) ne 'udeb') {
+        if (    $desc
+            and $processable->debian_control->installable_package_type($bin)ne
+            'udeb') {
             push @descriptions, [$bin, split("\n", $desc, 2)];
         }
 
@@ -331,7 +351,9 @@ sub source {
         }
 
         # Check mismatches in archive area.
-        $bin_area = $processable->binary_field($bin, 'section');
+        $bin_area
+          = $processable->debian_control->installable_fields($bin)
+          ->value('Section');
         $seen_main = 1 if not $bin_area and ($area // '') eq 'main';
         next unless $area && $bin_area;
 
@@ -378,22 +400,25 @@ sub source {
     for my $short (keys %short_descriptions) {
         # Assume that substvars are correctly handled
         next if $short =~ m/\$\{.+\}/;
-        $self->tag('duplicate-short-description',
-            @{$short_descriptions{$short}})
-          if scalar @{$short_descriptions{$short}} > 1;
+        $self->tag(
+            'duplicate-short-description',
+            sort @{$short_descriptions{$short}}
+        )if scalar @{$short_descriptions{$short}} > 1;
     }
 
     # check for duplicate long description
     for my $long (keys %long_descriptions) {
         # Assume that substvars are correctly handled
         next if $long =~ m/\$\{.+\}/;
-        $self->tag('duplicate-long-description', @{$long_descriptions{$long}})
+        $self->tag('duplicate-long-description',
+            sort @{$long_descriptions{$long}})
           if scalar @{$long_descriptions{$long}} > 1;
     }
 
     # check the syntax of the Build-Profiles field
     for my $bin (@package_names) {
-        my $raw = $processable->binary_field($bin, 'build-profiles');
+        my $raw = $processable->debian_control->installable_fields($bin)
+          ->value('Build-Profiles');
         next unless $raw;
         if (
             $raw!~ m{^\s*              # skip leading whitespace
@@ -435,7 +460,11 @@ sub source {
     }
 
     # Check Rules-Requires-Root
-    if (defined(my $r3 = $processable->source_field('rules-requires-root'))) {
+    if (
+        defined(
+            my $r3 = $processable->debian_control->source_fields->value(
+                'Rules-Requires-Root'))
+    ) {
         if ($r3 eq 'no') {
             $self->tag('rules-does-not-require-root');
         } else {
@@ -445,7 +474,11 @@ sub source {
         $self->tag('rules-requires-root-missing');
     }
 
-    if ($processable->source_field('rules-requires-root', 'no') eq 'no') {
+    if ((
+            $processable->debian_control->source_fields->value(
+                'Rules-Requires-Root')// 'no'
+        ) eq 'no'
+    ) {
       BINARY:
         foreach my $proc ($group->get_binary_processables) {
             my $pkg = $proc->name;
@@ -464,7 +497,8 @@ sub source {
         # The Architecture field is mandatory and dpkg-buildpackage
         # will already bail out if it's missing, so we don't need to
         # check that.
-        my $raw = $processable->binary_field($bin, 'architecture');
+        my $raw = $processable->debian_control->installable_fields($bin)
+          ->value('Architecture');
         if ($raw =~ /\n./) {
             $self->tag('multiline-architecture-field',$bin);
         }
@@ -480,13 +514,15 @@ sub source {
           unless $relation->implies('${gir:Depends}');
     }
 
-    if ($processable->relation('build-depends')
+    if ($processable->relation('Build-Depends')
         ->implies('golang-go | golang-any')) {
         # Verify that golang binary packages set Built-Using (except for
         # arch:all library packages).
         foreach my $bin (@package_names) {
-            my $bu = $processable->binary_field($bin, 'built-using');
-            my $arch = $processable->binary_field($bin, 'architecture');
+            my $bu = $processable->debian_control->installable_fields($bin)
+              ->value('Built-Using');
+            my $arch = $processable->debian_control->installable_fields($bin)
+              ->value('Architecture');
             if ($arch eq 'all') {
                 $self->tag('built-using-field-on-arch-all-package', $bin)
                   if defined($bu);
@@ -499,15 +535,19 @@ sub source {
         }
 
         $self->tag('missing-xs-go-import-path-for-golang-package')
-          unless $processable->source_field('xs-go-import-path', '');
+          unless (
+            $processable->debian_control->source_fields->value(
+                'XS-Go-Import-Path')// EMPTY
+          );
     }
 
     my $changes = $group->changes;
     $self->tag('source-only-upload-to-non-free-without-autobuild')
       if defined($changes)
-      and $changes->field('architecture', '') eq 'source'
+      and ($changes->fields->value('Architecture') // EMPTY) eq 'source'
       and $processable->is_non_free
-      and $processable->source_field('xs-autobuild', 'no') eq 'no';
+      and ($processable->debian_control->source_fields->value('XS-Autobuild')
+        // 'no')eq 'no';
 
     return;
 }
@@ -573,8 +613,9 @@ sub check_dev_depends {
                 # arch:all as well.  The version-substvars check
                 # handles that for us.
                 next
-                  if $processable->binary_field($target, 'architecture', '')eq
-                  'all'
+                  if (
+                    $processable->debian_control->installable_fields($target)
+                    ->value('Architecture')// EMPTY) eq 'all'
                   && $versions[0] =~ /^\s*=\s*\$\{source:Version\}/;
                 $self->tag('weak-library-dev-dependency',
                     "$package on $depends[0]");
