@@ -34,7 +34,7 @@ use Unicode::UTF8 qw[valid_utf8 decode_utf8];
 use XML::LibXML;
 
 use Lintian::Data;
-use Lintian::Deb822Parser qw(parse_dpkg_control_string);
+use Lintian::Deb822::Parser qw(parse_dpkg_control_string);
 use Lintian::Relation::Version qw(versions_compare);
 use Lintian::Spelling qw(check_spelling);
 
@@ -69,11 +69,11 @@ my $BAD_SHORT_LICENSES = Lintian::Data->new(
 my $dep5_last_normative_change = '0+svn~166';
 my $dep5_last_overhaul         = '0+svn~148';
 my %dep5_renamed_fields        = (
-    'format-specification' => 'format',
-    'maintainer'           => 'upstream-contact',
-    'upstream-maintainer'  => 'upstream-contact',
-    'contact'              => 'upstream-contact',
-    'name'                 => 'upstream-name',
+    'Format-Specification' => 'Format',
+    'Maintainer'           => 'Upstream-Contact',
+    'Upstream-Maintainer'  => 'Upstream-Contact',
+    'Contact'              => 'Upstream-Contact',
+    'Name'                 => 'Upstream-Name',
 );
 
 sub spelling_tag_emitter {
@@ -88,40 +88,34 @@ sub source {
 
     my $debian_dir = $self->processable->patched->resolve_path('debian/');
     return
-      unless $debian_dir;
+      unless defined $debian_dir;
 
-    my $file = $debian_dir->child('copyright');
+    my @installables = $self->processable->debian_control->installables;
+    my @additional = map { $_ . '.copyright' } @installables;
 
-    unless ($file) {
+    my @candidates = ('copyright', @additional);
+    my @files = grep { defined } map { $debian_dir->child($_) } @candidates;
 
-        # also look for <pkgname>.copyright for a single installable
-        my @installables = $self->processable->binaries;
-        if (scalar @installables == 1) {
+    # look for <pkgname>.copyright for a single installable
+    if (@files == 1) {
+        my $single = $files[0];
 
-            $file = $debian_dir->child($installables[0] . '.copyright');
-            $self->tag('named-copyright-for-single-installable', $file->name)
-              if $file;
-        }
-
-        unless ($file) {
-            $self->tag('no-debian-copyright-in-source');
-            return;
-        }
-
-    } elsif ($file->is_symlink) {
-        $self->tag('debian-copyright-is-symlink');
+        $self->tag('named-copyright-for-single-installable', $single->name)
+          unless $single->name eq 'debian/copyright';
     }
 
-    unless ($file->is_valid_utf8) {
+    $self->tag('no-debian-copyright-in-source')
+      unless @files;
 
-        $self->tag('debian-copyright-file-uses-obsolete-national-encoding');
-        return;
-    }
+    my @symlinks = grep { $_->is_symlink } @files;
+    $self->tag('debian-copyright-is-symlink', $_->name) for @symlinks;
 
-    my $contents = $file->decoded_utf8;
+    # another check complains about legacy encoding, if needed
+    my @valid_utf8 = grep { $_->is_valid_utf8 } @files;
 
-    $self->check_dep5_copyright($contents);
-    $self->check_apache_notice_files($contents);
+    $self->check_dep5_copyright($_)for @valid_utf8;
+
+    $self->check_apache_notice_files($_)for @valid_utf8;
 
     return;
 }
@@ -189,15 +183,16 @@ sub find_dep5_version {
 }
 
 sub check_apache_notice_files {
-    my ($self, $contents) = @_;
+    my ($self, $file) = @_;
 
+    my $contents = $file->decoded_utf8;
     return
-      unless $contents =~ m/apache[-\s]+2\./i;
+      unless $contents =~ /apache[-\s]+2\./i;
 
     my @notice_files = grep {
-              $_->basename =~ m/^NOTICE(\.txt)?$/
+              $_->basename =~ /^NOTICE(\.txt)?$/
           and $_->is_open_ok
-          and $_->bytes =~ m/apache/i
+          and $_->bytes =~ /apache/i
     } $self->processable->patched->sorted_list;
     return
       unless @notice_files;
@@ -206,7 +201,7 @@ sub check_apache_notice_files {
     return
       unless @binaries;
 
-    foreach my $binary (@binaries) {
+    for my $binary (@binaries) {
 
         # look at all path names in the package
         my @names = map { $_->name } $binary->installed->sorted_list;
@@ -221,13 +216,15 @@ sub check_apache_notice_files {
     }
 
     $self->tag('missing-notice-file-for-apache-license',
-        join(' ', @notice_files));
+        join(SPACE, @notice_files));
 
     return;
 }
 
 sub check_dep5_copyright {
-    my ($self, $contents) = @_;
+    my ($self, $copyright_file) = @_;
+
+    my $contents = $copyright_file->decoded_utf8;
 
     if ($contents =~ /^Files-Excluded:/m) {
 
@@ -239,7 +236,8 @@ sub check_dep5_copyright {
               || $self->processable->native;
 
         } else {
-            $self->tag('files-excluded-without-copyright-format-1.0');
+            $self->tag('files-excluded-without-copyright-format-1.0',
+                $copyright_file->name);
         }
     }
 
@@ -255,7 +253,7 @@ sub check_dep5_copyright {
                ) }x
     ){
 
-        $self->tag('no-dep5-copyright');
+        $self->tag('no-dep5-copyright', $copyright_file->name);
         return;
     }
 
@@ -336,28 +334,29 @@ sub parse_dep5 {
           if length $new_name;
     }
 
-    $self->check_files_excluded($first_para->{'files-excluded'} // '')
+    $self->check_files_excluded($first_para->{'Files-Excluded'} // '')
       unless $self->processable->native;
 
     $self->tag('copyright-excludes-files-in-native-package')
-      if exists $first_para->{'files-excluded'} && $self->processable->native;
+      if exists $first_para->{'Files-Excluded'} && $self->processable->native;
 
     $self->tag('missing-field-in-dep5-copyright',
-        'format',"(line $lines[0]{'format'})")
-      if none { defined $first_para->{$_} } qw(format format-specification);
+        'Format',"(line $lines[0]{'Format'})")
+      if none { defined $first_para->{$_} } qw(Format Format-Specification);
 
+    my $debian_control = $self->processable->debian_control;
     $self->tag('missing-explanation-for-contrib-or-non-free-package')
-      if $self->processable->source_field('section', '')
+      if ($debian_control->source_fields->value('Section') // EMPTY)
       =~ m{^(contrib|non-free)(/.+)?$}
-      and none { defined $first_para->{$_} } qw(comment disclaimer);
+      and none { defined $first_para->{$_} } qw(Comment Disclaimer);
 
     $self->tag('missing-explanation-for-repacked-upstream-tarball')
       if $self->processable->repacked
-      and none { defined $first_para->{$_} } qw(comment files-excluded)
-      and ($first_para->{'source'} // '') =~ m{^https?://};
+      and none { defined $first_para->{$_} } qw(Comment Files-Excluded)
+      and ($first_para->{'Source'} // '') =~ m{^https?://};
 
     my (undef, $full_license_field, undef,@short_licenses_field)
-      = $self->parse_license($first_para->{'license'}, 1);
+      = $self->parse_license($first_para->{'License'}, 1);
 
     for my $short_license (@short_licenses_field) {
         $required_standalone_licenses{$short_license} = 0
@@ -390,16 +389,15 @@ sub parse_dep5 {
 
     my (@commas_in_files, %file_para_coverage, %file_licenses);
     my %file_coverage = map { $_ => 0 } @shippedfiles;
-    my $i = 0;
     my $current_line = 0;
     my $commas_in_files = any { /,/s } @allpaths;
 
+    my $position = 1;
     for my $para (@dep5) {
-        $i++;
-        $current_line = $lines[$i]{'START-OF-PARAGRAPH'};
-        my $files = $para->{files};
-        my $license   = $para->{license};
-        my $copyright = $para->{copyright};
+        $current_line = $lines[$position]{'START-OF-PARAGRAPH'};
+        my $files = $para->{Files};
+        my $license   = $para->{License};
+        my $copyright = $para->{Copyright};
 
         if (    not defined $files
             and defined $license
@@ -411,7 +409,7 @@ sub parse_dep5 {
 
             # If it is the first paragraph, it might be an instance of
             # the (no-longer) optional "first Files-field".
-            $files = '*' if $i == 1;
+            $files = '*' if $position == 1;
         }
 
         if (defined $license and not defined $files) {
@@ -436,17 +434,17 @@ sub parse_dep5 {
                             "(paragraph at line $current_line)"
                         );
                     } else {
-                        $standalone_licenses{$_} = $i;
+                        $standalone_licenses{$_} = $position;
                         $full_licenses_seen{$_} = $current_line;
                     }
-                    $short_licenses_seen{$_} = $i;
+                    $short_licenses_seen{$_} = $position;
                 }
             }
         }elsif (defined $files) {
             if ($files =~ m/\A\s*\Z/mxs) {
                 $self->tag(
                     'missing-field-in-dep5-copyright',
-                    'files',
+                    'Files',
                     '(empty field,',
                     "paragraph at line $current_line)"
                 );
@@ -455,7 +453,7 @@ sub parse_dep5 {
             $self->tag(
                 'global-files-wildcard-not-first-paragraph-in-dep5-copyright',
                 "(paragraph at line $current_line)"
-            ) if $files eq '*' and $i > 1;
+            ) if $files eq '*' and $position > 1;
 
             my @listedfiles = split(SPACE, $files);
 
@@ -468,7 +466,7 @@ sub parse_dep5 {
 
             # Files paragraph
             if (not @commas_in_files and $files =~ /,/) {
-                @commas_in_files = ($i, 'files');
+                @commas_in_files = ($position, 'Files');
             }
 
             my ($found_license, $full_license, $short_license, @short_licenses)
@@ -569,9 +567,9 @@ sub parse_dep5 {
             }
             if ($found_license) {
                 for (@short_licenses) {
-                    $short_licenses_seen{$_} = $i;
+                    $short_licenses_seen{$_} = $position;
                     if (not defined($full_license)) {
-                        $required_standalone_licenses{$_} = $i;
+                        $required_standalone_licenses{$_} = $position;
                     } else {
                         if(defined($full_licenses_seen{$_})
                             and $_ ne 'public-domain') {
@@ -585,16 +583,16 @@ sub parse_dep5 {
                 }
             }else {
                 $self->tag('missing-field-in-dep5-copyright',
-                    'license',"(paragraph at line $current_line)");
+                    'License',"(paragraph at line $current_line)");
             }
 
             if (not defined $copyright) {
                 $self->tag('missing-field-in-dep5-copyright',
-                    'copyright',"(paragraph at line $current_line)");
+                    'Copyright',"(paragraph at line $current_line)");
             }elsif ($copyright =~ m/\A\s*\Z/mxs) {
                 $self->tag(
                     'missing-field-in-dep5-copyright',
-                    'copyright',
+                    'Copyright',
                     '(empty field,',
                     "paragraph at line $current_line)"
                 );
@@ -607,7 +605,11 @@ sub parse_dep5 {
                 $current_line
             );
         }
+
+    } continue {
+        $position++;
     }
+
     if (@commas_in_files and not $commas_in_files) {
         my ($paragraph_no, $field_name) = @commas_in_files;
         $self->tag(
@@ -665,7 +667,7 @@ sub parse_dep5 {
           for sort keys %file_para_coverage;
     }
 
-    while ((my $license, $i) = each %required_standalone_licenses) {
+    while (my ($license,$i) = each %required_standalone_licenses) {
         if (not defined $standalone_licenses{$license}) {
             $self->tag('missing-license-paragraph-in-dep5-copyright',
                 $license,
@@ -677,7 +679,7 @@ sub parse_dep5 {
         }
 
     }
-    while ((my $license, $i) = each %standalone_licenses) {
+    while (my ($license, $i) = each %standalone_licenses) {
         if (not defined $required_standalone_licenses{$license}) {
             $self->tag('unused-license-paragraph-in-dep5-copyright',
                 $license,
@@ -685,7 +687,7 @@ sub parse_dep5 {
         }
     }
   LICENSE:
-    while ((my $license, $i) = each %short_licenses_seen) {
+    while (my ($license, $i) = each %short_licenses_seen) {
         if ($license =~ m,\s,) {
             if($license =~ m,[^ ]+ \s+ with \s+ (.*),x) {
                 my $exceptiontext = $1;
@@ -899,7 +901,7 @@ sub binary {
 
     # looking up entry without slash first; index should not be so picky
     my $doclink = $self->processable->installed->lookup(
-        'usr/share/doc/' . $self->package);
+        'usr/share/doc/' . $self->processable->name);
     if ($doclink && $doclink->is_symlink) {
 
         # check if this symlink references a directory elsewhere
@@ -940,7 +942,7 @@ sub binary {
     }
 
     my $docdir = $self->processable->installed->lookup(
-        'usr/share/doc/' . $self->package . '/');
+        'usr/share/doc/' . $self->processable->name . '/');
     unless ($docdir) {
         $self->tag('no-copyright-file');
         return;
@@ -969,7 +971,7 @@ sub binary {
 
         # #522827: special exception for perl for now
         $self->tag('no-copyright-file')
-          unless $self->package eq 'perl';
+          unless $self->processable->name eq 'perl';
 
         return;
     }
@@ -977,13 +979,11 @@ sub binary {
     my $dcopy
       = path($self->processable->groupdir)->child('copyright')->stringify;
 
-    # check that copyright is UTF-8 encoded
     my $bytes = path($dcopy)->slurp;
-    unless (valid_utf8($bytes)) {
 
-        $self->tag('debian-copyright-file-uses-obsolete-national-encoding');
-        return;
-    }
+    # another check complains about invalid encoding
+    return
+      unless valid_utf8($bytes);
 
     # check contents of copyright file
     my $contents = decode_utf8($bytes);
@@ -1204,7 +1204,7 @@ qr/GNU (?:Lesser|Library) General Public License|(?-i:\bLGPL\b)/i
     if ($found && !$linked) {
         $self->tag('copyright-without-copyright-notice')
           unless $contents
-          =~ /(?:Copyright|Copr\.|\302\251)(?:.*|[\(C\):\s]+)\b\d{4}\b
+          =~ /(?:Copyright|Copr\.|©)(?:.*|[\(C\):\s]+)\b\d{4}\b
                |\bpublic(?:\s+|-)domain\b/xi;
     }
 
@@ -1224,9 +1224,11 @@ qr/GNU (?:Lesser|Library) General Public License|(?-i:\bLGPL\b)/i
         !~ m{exception|exemption|/usr/share/common-licenses/(?!GPL)\S}){
 
         my @depends
-          = split(/\s*,\s*/, $self->processable->field('depends') // EMPTY);
+          = split(/\s*,\s*/,
+            $self->processable->fields->value('Depends') // EMPTY);
         my @predepends
-          = split(/\s*,\s*/,$self->processable->field('pre-depends') // EMPTY);
+          = split(/\s*,\s*/,
+            $self->processable->fields->value('Pre-Depends') // EMPTY);
 
         $self->tag('possible-gpl-code-linked-with-openssl')
           if any { /^libssl[0-9.]+(?:\s|\z)/ && !/\|/ }
@@ -1265,7 +1267,8 @@ sub check_cross_link {
     if ($source) {
         # source package is available; check its list of binaries
         return
-          if defined $source->binary_package_type($foreign);
+          if
+          defined $source->debian_control->installable_package_type($foreign);
 
         $self->tag('usr-share-doc-symlink-to-foreign-package', $foreign);
 
@@ -1318,7 +1321,7 @@ sub check_names_texts {
     return $text_check->(\$contents)
       if $@;
 
-    my @licenses = grep { length } map { $_->{license} } @paragraphs;
+    my @licenses = grep { length } map { $_->{License} } @paragraphs;
     for my $license (@licenses) {
 
         my ($name, $text) = ($license =~ /^\s*([^\r\n]+)\r?\n(.*)\z/s);
