@@ -1,6 +1,7 @@
 # debian/debconf -- lintian check script -*- perl -*-
 
 # Copyright © 2001 Colin Watson
+# Copyright © 2020 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -25,12 +26,17 @@ use warnings;
 use utf8;
 use autodie;
 
+use List::MoreUtils qw(none);
 use Path::Tiny;
 
-use Lintian::Deb822Parser qw(parse_dpkg_control_string :constants);
+use Lintian::Deb822::File;
+use Lintian::Deb822::Parser qw(:constants);
 use Lintian::Relation;
 use Lintian::Util qw($PKGNAME_REGEX);
 
+use constant EMPTY => q{};
+use constant SPACE => q{ };
+
 use Moo;
 use namespace::clean;
 
@@ -42,7 +48,7 @@ with 'Lintian::Check';
 # behavior. Likewise, help is supported as of cdebconf 0.143 but is not yet
 # supported by debconf.
 my %template_fields
-  = map { $_ => 1 } qw(template type choices indices default description help);
+  = map { $_ => 1 } qw(Template Type Choices Indices Default Description Help);
 
 # From debconf-devel(7), section 'THE TEMPLATES FILE', up to date with debconf
 # version 1.5.24.
@@ -72,55 +78,42 @@ my $ANY_DEBCONF = Lintian::Relation->new(
 sub source {
     my ($self) = @_;
 
-    my @binaries = $self->processable->binaries;
-    my @files = map { "$_.templates" } @binaries;
-    push @files, 'templates';
+    my @catalogs= (
+        'templates',
+        map { "$_.templates" }$self->processable->debian_control->installables
+    );
+    my @files = grep { defined }
+      map { $self->processable->patched->resolve_path("debian/$_") } @catalogs;
 
-    foreach my $file (@files) {
-        my $dfile = "debian/$file";
-        my $templates_file = $self->processable->patched->resolve_path($dfile);
-        my $binary = $file;
-        $binary =~ s/\.?templates$//;
-        # Single binary package (so @files contains "templates" and
-        # "binary.templates")?
-        if (!$binary && @files == 2) {
-            $binary = $binaries[0];
+    my @utf8 = grep { $_->is_valid_utf8 } @files;
+    for my $file (@utf8) {
+
+        my $contents = $file->decoded_utf8;
+        my $deb822 = Lintian::Deb822::File->new;
+
+        my @templates;
+        eval {
+            @templates
+              = $deb822->parse_string($contents, DCTRL_DEBCONF_TEMPLATE);
+        };
+
+        if (length $@) {
+            chomp $@;
+
+            $@ =~ s/^syntax error in //;
+            $self->tag('syntax-error-in-debconf-template',"$file: $@");
+
+            next;
         }
 
-        if ($templates_file && $templates_file->is_open_ok) {
+        my @unsplit_choices
+          = grep {
+            defined $_->value('Template') && defined $_->value('_Choices')}
+          @templates;
 
-            unless ($templates_file->is_valid_utf8) {
-                $self->tag('national-encoding-in-debconf-template',
-                    $templates_file->name);
-                next;
-            }
-
-            my $contents = $templates_file->decoded_utf8;
-
-            my @templates;
-            eval {
-                @templates
-                  = parse_dpkg_control_string($contents,
-                    DCTRL_DEBCONF_TEMPLATE);
-            };
-            if ($@) {
-                chomp $@;
-                $@ =~ s/^internal error: //;
-                $@ =~ s/^syntax error in //;
-                $self->tag('syntax-error-in-debconf-template',"$file: $@");
-                next;
-            }
-
-            foreach my $template (@templates) {
-                if (    exists $template->{template}
-                    and exists $template->{_choices}) {
-                    $self->tag(
-                        'template-uses-unsplit-choices',
-                        "$binary - $template->{template}"
-                    );
-                }
-            }
-        }
+        $self->tag('template-uses-unsplit-choices',
+            $file->name, $_->value('Template'))
+          for @unsplit_choices;
     }
 
     return;
@@ -129,16 +122,8 @@ sub source {
 sub installable {
     my ($self) = @_;
 
-    my $pkg = $self->package;
-    my $type = $self->type;
-    my $processable = $self->processable;
-
-    my ($seenconfig, $seentemplates, $usespreinst);
-
-    my $preinst = $processable->control->lookup('preinst');
-    my $ctrl_config = $processable->control->lookup('config');
-    my $ctrl_templates = $processable->control->lookup('templates');
-
+    my $usespreinst;
+    my $preinst = $self->processable->control->lookup('preinst');
     if ($preinst and $preinst->is_file and $preinst->is_open_ok) {
         open(my $fd, '<', $preinst->unpacked_path);
         while (<$fd>) {
@@ -152,32 +137,48 @@ sub installable {
         close($fd);
     }
 
-    $seenconfig = 1 if $ctrl_config and $ctrl_config->is_file;
+    my $seenconfig;
+    my $ctrl_config = $self->processable->control->lookup('config');
+    if (defined $ctrl_config && $ctrl_config->is_file) {
+
+        $self->tag('debconf-config-not-executable')
+          unless $ctrl_config->is_executable;
+
+        $seenconfig = 1;
+    }
+
+    my $seentemplates;
+    my $ctrl_templates = $self->processable->control->lookup('templates');
     $seentemplates = 1 if $ctrl_templates and $ctrl_templates->is_file;
 
     # This still misses packages that use debconf only in the postrm.
     # Packages that ask debconf questions in the postrm should load
     # the confmodule in the postinst so that debconf can register
     # their templates.
-    return unless $seenconfig or $seentemplates or $usespreinst;
+    return
+         unless $seenconfig
+      or $seentemplates
+      or $usespreinst;
 
     # parse depends info for later checks
 
     # Consider every package to depend on itself.
     my $selfrel;
-    if (defined $processable->field('version')) {
-        $_ = $processable->field('version');
-        $selfrel = "$pkg (= $_)";
+    if (defined $self->processable->fields->value('Version')) {
+        $_ = $self->processable->fields->value('Version');
+        $selfrel = $self->processable->name . " (= $_)";
     } else {
-        $selfrel = "$pkg";
+        $selfrel = $self->processable->name;
     }
 
     # Include self and provides as a package providing debconf presumably
     # satisfies its own use of debconf (if any).
     my $selfrelation
-      = Lintian::Relation->and($processable->relation('provides'), $selfrel);
+      = Lintian::Relation->and($self->processable->relation('Provides'),
+        $selfrel);
     my $alldependencies
-      = Lintian::Relation->and($processable->relation('strong'),$selfrelation);
+      = Lintian::Relation->and($self->processable->relation('strong'),
+        $selfrelation);
 
     # See if the package depends on dbconfig-common.  Packages that do
     # are allowed to have a config file with no templates, since they
@@ -190,146 +191,149 @@ sub installable {
     } elsif ($seentemplates
         and not $seenconfig
         and not $usespreinst
-        and $type ne 'udeb') {
+        and $self->processable->type ne 'udeb') {
         $self->tag('no-debconf-config');
     }
 
-    if ($seenconfig and not $ctrl_config->is_executable) {
-        $self->tag('debconf-config-not-executable');
-    }
-
     # Lots of template checks.
 
-    my (@templates, %potential_db_abuse, @templates_seen);
-
+    my @templates;
     if ($seentemplates) {
 
         if ($ctrl_templates->is_valid_utf8) {
             my $contents = $ctrl_templates->decoded_utf8;
+            my $deb822 = Lintian::Deb822::File->new;
+
             eval {
                 # $seentemplates (above) will be false if $ctrl_templates is a
                 # symlink or not a file, so this should be safe without
                 # (re-checking) with -f/-l.
-                @templates= parse_dpkg_control_string($contents,
-                    DCTRL_DEBCONF_TEMPLATE);
+                @templates
+                  = $deb822->parse_string($contents,DCTRL_DEBCONF_TEMPLATE);
             };
-            if ($@) {
+
+            if (length $@) {
                 chomp $@;
-                $@ =~ s/^internal error: //;
+
                 $@ =~ s/^syntax error in //;
-                $self->tag('syntax-error-in-debconf-template',"templates: $@");
+                $self->tag(
+                    'syntax-error-in-debconf-template',
+                    "DEBIAN/$ctrl_templates: $@"
+                );
+
                 @templates = ();
             }
         }
     }
 
-    foreach my $template (@templates) {
-        my $isselect = '';
+    my @templates_seen;
+    my %potential_db_abuse;
+    for my $template (@templates) {
+        my $isselect = EMPTY;
 
-        if (not exists $template->{template}) {
+        my $name = $template->value('Template');
+        if (!defined $name) {
             $self->tag('no-template-name');
-            $template->{template} = 'no-template-name';
+            $name = 'no-template-name';
+
         } else {
-            push @templates_seen, $template->{template};
-            if ($template->{template}!~m|[A-Za-z0-9.+-](?:/[A-Za-z0-9.+-])|) {
-                $self->tag('malformed-template-name', "$template->{template}");
-            }
+            push @templates_seen, $name;
+            $self->tag('malformed-template-name', $name)
+              unless $name =~ m{[A-Za-z0-9.+-](?:/[A-Za-z0-9.+-])};
         }
 
-        if (not exists $template->{type}) {
-            $self->tag('no-template-type', "$template->{template}");
-        } elsif (not $valid_types{$template->{type}}) {
+        my $type = $template->value('Type');
+        if (not defined $type) {
+            $self->tag('no-template-type', $name);
+
+        } elsif (!$valid_types{$type}) {
             # cdebconf has a special "entropy" type
-            $self->tag('unknown-template-type', "$template->{type}")
-              unless ($template->{type} eq 'entropy'
-                and $alldependencies->implies('cdebconf'));
-        } elsif ($template->{type} eq 'select') {
+            $self->tag('unknown-template-type', $type)
+              unless $type eq 'entropy'
+              && $alldependencies->implies('cdebconf');
+
+        } elsif ($type eq 'select' || $type eq 'multiselect') {
             $isselect = 1;
-        } elsif ($template->{type} eq 'multiselect') {
-            $isselect = 1;
-        } elsif ($template->{type} eq 'boolean') {
-            $self->tag(
-                'boolean-template-has-bogus-default',
-                "$template->{template} $template->{default}"
-              )
-              if defined $template->{default}
-              and $template->{default} ne 'true'
-              and $template->{default} ne 'false';
+
+        } elsif ($type eq 'boolean') {
+            my $default = $template->value('Default');
+            $self->tag('boolean-template-has-bogus-default', $name, $default)
+              if defined $default
+              && (none { $default eq $_ } ('true', 'false'));
         }
 
-        if ($template->{choices} && ($template->{choices} !~ /^\s*$/)) {
-            my $nrchoices = count_choices($template->{choices});
-            for my $key (keys %$template) {
-                if ($key =~ /^choices-/) {
-                    if (!$template->{$key} || ($template->{$key} =~ /^\s*$/)){
-                        $self->tag(
-                            'empty-translated-choices',
-                            "$template->{template} $key"
-                        );
+        my $choices = $template->value('Choices');
+        if (defined $choices && $choices !~ /^\s*$/) {
+
+            my $nrchoices = count_choices($choices);
+            for my $key ($template->names) {
+
+                if ($key =~ /^Choices-/) {
+                    my $translated = $template->value($key);
+                    if (!length($translated) || $translated =~ /^\s*$/){
+                        $self->tag('empty-translated-choices', $name, $key);
                     }
-                    if (count_choices($template->{$key}) != $nrchoices) {
-                        $self->tag(
-                            'mismatch-translated-choices',
-                            "$template->{template} $key"
-                        );
+
+                    if (count_choices($translated) != $nrchoices) {
+                        $self->tag('mismatch-translated-choices', $name, $key);
                     }
                 }
             }
-            if ($template->{choices} =~ /^\s*(yes\s*,\s*no|no\s*,\s*yes)\s*$/i)
-            {
-                $self->tag('select-with-boolean-choices',
-                    "$template->{template}");
-            }
+
+            $self->tag('select-with-boolean-choices', $name)
+              if $choices =~ /^\s*(yes\s*,\s*no|no\s*,\s*yes)\s*$/i;
         }
 
-        if ($isselect and not exists $template->{choices}) {
-            $self->tag('select-without-choices', "$template->{template}");
-        }
+        $self->tag('select-without-choices', $name)
+          if $isselect && !defined $choices;
 
-        if (not exists $template->{description}) {
-            $self->tag('no-template-description', "$template->{template}");
-        } elsif ($template->{description}=~m/^\s*(.*?)\s*?\n\s*\1\s*$/) {
+        my $description = $template->value('Description');
+        $self->tag('no-template-description', $name)
+          unless defined $description
+          || defined $template->value('_Description');
+
+        if (($description // EMPTY) =~ /^\s*(.*?)\s*?\n\s*\1\s*$/){
             # Check for duplication. Should all this be folded into the
             # description checks?
-            $self->tag('duplicate-long-description-in-template',
-                "$template->{template}");
+            $self->tag('duplicate-long-description-in-template',$name);
         }
 
         my %languages;
-        foreach my $field (sort keys %$template) {
+        for my $field ($template->names) {
             # Tests on translations
             my ($mainfield, $lang) = split m/-/, $field, 2;
             if (defined $lang) {
                 $languages{$lang}{$mainfield}=1;
             }
-            unless ($template_fields{$mainfield}){ # Ignore language codes here
-                $self->tag(
-                    'unknown-field-in-templates',
-                    "$template->{template} $field"
-                );
+            my $stripped = $mainfield;
+            $stripped =~ s/^_//;
+            unless ($template_fields{$stripped}) {
+                # Ignore language codes here
+                $self->tag('unknown-field-in-templates',$name, $field);
             }
         }
 
-        if ($template->{template} && $template->{type}) {
-            $potential_db_abuse{$template->{template}} = 1
-              if ( ($template->{type} eq 'note')
-                or ($template->{type} eq 'text'));
+        if (length $name && length $type) {
+            $potential_db_abuse{$name} = 1
+              if $type eq 'note' || $type eq 'text';
         }
 
         # Check the description against the best practices in the
         # Developer's Reference, but skip all templates where the
         # short description contains the string "for internal use".
         my ($short, $extended);
-        if (defined $template->{description}) {
-            ($short, $extended) = split(/\n/, $template->{description}, 2);
+        if (defined $description) {
+            ($short, $extended) = split(/\n/, $description, 2);
             unless (defined $short) {
-                $short = $template->{description};
-                $extended = '';
+                $short = $description;
+                $extended = EMPTY;
             }
         } else {
-            ($short, $extended) = ('', '');
+            $short = EMPTY;
+            $extended = EMPTY;
         }
-        my $ttype = $template->{type} || '';
+
+        my $ttype = $type // EMPTY;
         unless ($short =~ /for internal use/i) {
             my $isprompt = grep { $_ eq $ttype } qw(string password);
             if ($isprompt) {
@@ -338,64 +342,59 @@ sub installable {
                     && (   $short !~ m/:$/
                         || $short =~ m/^(what|who|when|where|which|how)/i)
                 ) {
-                    $self->tag('malformed-prompt-in-templates',
-                        $template->{template});
+                    $self->tag('malformed-prompt-in-templates',$name);
                 }
             }
             if ($isselect) {
                 if ($short =~ /^(Please|Cho+se|Enter|Select|Specify|Give)/) {
-                    $self->tag('using-imperative-form-in-templates',
-                        $template->{template});
+                    $self->tag('using-imperative-form-in-templates',$name);
                 }
             }
             if ($ttype eq 'boolean') {
                 if ($short !~ /\?/) {
-                    $self->tag('malformed-question-in-templates',
-                        $template->{template});
+                    $self->tag('malformed-question-in-templates',$name);
                 }
             }
-            if (defined($extended) && $extended =~ /[^\?]\?(\s+|$)/) {
+            if (defined $extended && $extended =~ /[^\?]\?(\s+|$)/) {
                 $self->tag(
                     'using-question-in-extended-description-in-templates',
-                    $template->{template});
+                    $name);
             }
             if ($ttype eq 'note') {
                 if ($short =~ /[.?;:]$/) {
-                    $self->tag('malformed-title-in-templates',
-                        $template->{template});
+                    $self->tag('malformed-title-in-templates',$name);
                 }
             }
             if (length($short) > 75) {
-                $self->tag('too-long-short-description-in-templates',
-                    $template->{template})
-                  unless $type eq 'udeb' && $ttype eq 'text';
+                $self->tag('too-long-short-description-in-templates',$name)
+                  unless $self->processable->type eq 'udeb'
+                  && $ttype eq 'text';
             }
-            if (defined $template->{description}) {
-                if ($template->{description}
+            if (defined $description) {
+                if ($description
                     =~ /(\A|\s)(I|[Mm]y|[Ww]e|[Oo]ur|[Oo]urs|mine|myself|ourself|me|us)(\Z|\s)/
                 ) {
-                    $self->tag('using-first-person-in-templates',
-                        $template->{template});
+                    $self->tag('using-first-person-in-templates',$name);
                 }
-                if (    $template->{description} =~ /[ \'\"]yes[ \'\",;.]/i
+                if (    $description =~ /[ \'\"]yes[ \'\",;.]/i
                     and $ttype eq 'boolean') {
                     $self->tag(
                         'making-assumptions-about-interfaces-in-templates',
-                        $template->{template});
+                        $name);
                 }
             }
 
             # Check whether the extended description is too long.
             if ($extended) {
                 my $lines = 0;
-                for my $string (split("\n", $extended)) {
+                for my $string (split(/\n/, $extended)) {
                     while (length($string) > 80) {
-                        my $pos = rindex($string, ' ', 80);
+                        my $pos = rindex($string, SPACE, 80);
                         if ($pos == -1) {
-                            $pos = index($string, ' ');
+                            $pos = index($string, SPACE);
                         }
                         if ($pos == -1) {
-                            $string = '';
+                            $string = EMPTY;
                         } else {
                             $string = substr($string, $pos + 1);
                             $lines++;
@@ -405,7 +404,7 @@ sub installable {
                 }
                 if ($lines > 20) {
                     $self->tag('too-long-extended-description-in-templates',
-                        $template->{template});
+                        $name);
                 }
             }
         }
@@ -417,7 +416,7 @@ sub installable {
     my (%templates_used, %template_aliases);
     for my $file (qw(config prerm postrm preinst postinst)) {
         my $potential_makedev = {};
-        my $path = $processable->control->lookup($file);
+        my $path = $self->processable->control->lookup($file);
         if ($path and $path->is_file and $path->is_open_ok) {
             my ($usesconfmodule, $obsoleteconfmodule, $db_input, $isdefault);
 
@@ -460,7 +459,7 @@ sub installable {
                     and not $config_calls_db_input) {
                     # TODO: Perl?
                     $self->tag('postinst-uses-db-input')
-                      unless $type eq 'udeb';
+                      unless $self->processable->type eq 'udeb';
                     $db_input=1;
                 }
                 if (m%/dev/%) {
@@ -471,8 +470,7 @@ sub installable {
                      [\"\']? (\S+?) [\"\']? \s+ (\S+)\s/xsm
                 ) {
                     my ($priority, $template) = ($1, $2);
-                    $templates_used{get_template_name($processable, $template)}
-                      = 1;
+                    $templates_used{$self->get_template_name($template)}= 1;
                     if ($priority !~ /^\$\S+$/) {
                         $self->tag('unknown-debconf-priority', "$file:$. $1")
                           unless ($valid_priorities{$priority});
@@ -490,7 +488,7 @@ sub installable {
                     m/ \A \s* (?:db_get|db_set(?:title)?) \s+ 
                        [\"\']? (\S+?) [\"\']? (?:\s|\Z)/xsm
                 ) {
-                    $templates_used{get_template_name($processable, $1)} = 1;
+                    $templates_used{$self->get_template_name($1)} = 1;
                 }
                 # Try to handle Perl somewhat.
                 if (   m/^\s*(?:.*=\s*get|set)\s*\(\s*[\"\'](\S+?)[\"\']/
@@ -514,7 +512,7 @@ sub installable {
             if ($file eq 'postinst' or $file eq 'config') {
                 unless ($usesconfmodule) {
                     $self->tag("$file-does-not-load-confmodule")
-                      unless ($type eq 'udeb'
+                      unless ($self->processable->type eq 'udeb'
                         || ($file eq 'postinst' && !$seenconfig));
                 }
             }
@@ -531,13 +529,13 @@ sub installable {
             close($fd);
         } elsif ($file eq 'postinst') {
             $self->tag('postinst-does-not-load-confmodule')
-              unless ($type eq 'udeb' || !$seenconfig);
+              unless ($self->processable->type eq 'udeb' || !$seenconfig);
         } elsif ($file eq 'postrm') {
             # Make an exception for debconf providing packages as some of
             # them (incl. "debconf" itself) cleans up in prerm and have no
             # postrm script at all.
             $self->tag('postrm-does-not-purge-debconf')
-              unless $type eq 'udeb'
+              unless $self->processable->type eq 'udeb'
               or $selfrelation->implies($ANY_DEBCONF);
         }
     }
@@ -558,7 +556,9 @@ sub installable {
             }
         }
 
-        unless ($used or $pkg eq 'debconf' or $type eq 'udeb') {
+        unless ($used
+            or $self->processable->name eq 'debconf'
+            or $self->processable->type eq 'udeb') {
             $self->tag('unused-debconf-template', $template)
               unless $template =~ m,^shared/packages-(wordlist|ispell)$,
               or $template =~ m,/languages$,;
@@ -569,9 +569,11 @@ sub installable {
     # package that might provide debconf functionality.
 
     if ($usespreinst) {
-        unless ($processable->relation('pre-depends')->implies($ANY_DEBCONF)) {
+        unless (
+            $self->processable->relation('Pre-Depends')->implies($ANY_DEBCONF))
+        {
             $self->tag('missing-debconf-dependency-for-preinst')
-              unless $type eq 'udeb';
+              unless $self->processable->type eq 'udeb';
         }
     } else {
         unless ($alldependencies->implies($ANY_DEBCONF) or $usesdbconfig) {
@@ -586,9 +588,11 @@ sub installable {
     # itself.
 
     return
-      if ($pkg eq 'debconf') || ($type eq 'udeb');
+      if ($self->processable->name eq 'debconf')
+      || ($self->processable->type eq 'udeb');
 
-    my @scripts = grep { $_->is_script } $processable->installed->sorted_list;
+    my @scripts
+      = grep { $_->is_script } $self->processable->installed->sorted_list;
     foreach my $file (@scripts) {
 
         next
@@ -633,9 +637,9 @@ sub count_choices {
 
 # Manually interpolate shell variables, eg. $DPKG_MAINTSCRIPT_PACKAGE
 sub get_template_name {
-    my ($processable, $name) = @_;
+    my ($self, $name) = @_;
 
-    my $package = $processable->name;
+    my $package = $self->processable->name;
     return $name =~ s/^\$DPKG_MAINTSCRIPT_PACKAGE/$package/r;
 }
 
