@@ -31,6 +31,8 @@ use List::MoreUtils qw(any);
 use Lintian::Data;
 use Lintian::Relation;
 
+use constant EMPTY => q{};
+
 use Moo;
 use namespace::clean;
 
@@ -90,24 +92,26 @@ sub check_file_overlap {
     for (my $i = 0 ; $i < scalar @sorted ; $i++) {
         my $processable = $sorted[$i];
 
-        my @p = grep { $_ } split(/,/, $processable->field('provides', ''));
+        my @p= grep { $_ }
+          split(/,/, ($processable->fields->value('Provides') // EMPTY));
         my $prov
           = Lintian::Relation->new(join(' |̈́ ', $processable->name, @p));
         for (my $j = $i ; $j < scalar @sorted ; $j++) {
             my $other = $sorted[$j];
 
-            my @op = grep { $_ } split(/,/, $other->field('provides', ''));
+            my @op= grep { $_ }
+              split(/,/, ($other->fields->value('Provides') // EMPTY));
             my $oprov= Lintian::Relation->new(join(' | ', $other->name, @op));
             # poor man's "Multi-arch: same" work-around.
             next if $processable->name eq $other->name;
 
             # $other conflicts/replaces with $processable
-            next if $other->relation('conflicts')->implies($prov);
-            next if $other->relation('replaces')->implies($processable->name);
+            next if $other->relation('Conflicts')->implies($prov);
+            next if $other->relation('Replaces')->implies($processable->name);
 
             # $processable conflicts/replaces with $other
-            next if $processable->relation('conflicts')->implies($oprov);
-            next if $processable->relation('replaces')->implies($other->name);
+            next if $processable->relation('Conflicts')->implies($oprov);
+            next if $processable->relation('Replaces')->implies($other->name);
 
             $self->overlap_check($processable, $processable, $other, $other);
         }
@@ -135,10 +139,10 @@ sub overlap_check {
 sub check_multiarch {
     my ($self, $processable, $deps) = @_;
 
-    my $ma = $processable->field('multi-arch', 'no');
+    my $ma = $processable->fields->value('Multi-Arch') // 'no';
     if ($ma eq 'same') {
         foreach my $dep (@$deps) {
-            my $dma = $dep->field('multi-arch', 'no');
+            my $dma = $dep->fields->value('Multi-Arch') // 'no';
             if ($dma eq 'same' or $dma eq 'foreign') {
                 1; # OK
             } else {
@@ -150,14 +154,16 @@ sub check_multiarch {
             }
         }
     } elsif ($ma ne 'same'
-        and $processable->field('section', 'none') =~ m,(?:^|/)debug$,) {
+        and ($processable->fields->value('Section') // 'none')
+        =~ m,(?:^|/)debug$,) {
         # Debug package that isn't M-A: same, exploit that (non-debug)
         # dependencies is (almost certainly) a package for which the
         # debug carries debug symbols.
         foreach my $dep (@$deps) {
-            my $dma = $dep->field('multi-arch', 'no');
-            if (    $dma eq 'same'
-                and $dep->field('section', 'none') !~ m,(?:^|/)debug$,){
+            my $dma = $dep->fields->value('Multi-Arch') // 'no';
+            if ($dma eq 'same'
+                and ($dep->fields->value('Section') // 'none')
+                !~ m,(?:^|/)debug$,){
 
                 # Debug package isn't M-A: same, but depends on a
                 # package that is from same source that isn't a debug
