@@ -20,8 +20,9 @@
 
 package Lintian::languages::fortran::gfortran;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 
 use Lintian::Util qw(open_gz);
 
@@ -32,7 +33,7 @@ use namespace::clean;
 
 with 'Lintian::Check';
 
-sub files {
+sub visit_installed_files {
     my ($self, $file) = @_;
 
     # file-info would be great, but files are zipped
@@ -71,7 +72,7 @@ sub files {
         return;
     }
 
-    my $depends = $self->processable->field('depends') // EMPTY;
+    my $depends = $self->processable->fields->value('Depends') // EMPTY;
     $self->tag('missing-prerequisite-for-gfortran-module', $file->name)
       unless $depends =~ /\bgfortran-mod-$module_version\b/;
 
