@@ -31,6 +31,8 @@ use Path::Tiny;
 
 use Lintian::Relation;
 
+use constant EMPTY => q{};
+
 use Moo;
 use namespace::clean;
 
@@ -39,12 +41,13 @@ with 'Lintian::Check';
 sub source {
     my ($self) = @_;
 
-    my $pkg = $self->package;
+    my $pkg = $self->processable->name;
     my $processable = $self->processable;
 
     # debian/control check
-    my @testsuites
-      = split(m/\s*,\s*/, $processable->source_field('testsuite') // q{});
+    my @testsuites= split(m/\s*,\s*/,
+        $processable->debian_control->source_fields->value('Testsuite')
+          // EMPTY);
     if (any { /^autopkgtest-pkg-nodejs$/ } @testsuites) {
         # Check control file exists in sources
         my $filename = 'debian/tests/pkg-js/test';
@@ -114,12 +117,12 @@ sub source {
     return;
 }
 
-sub files {
+sub visit_installed_files {
     my ($self, $file) = @_;
     return if $file->is_dir;
 
     return
-      if $self->package =~ /-dbg$/;
+      if $self->processable->name =~ /-dbg$/;
 
     # Warn if a file is installed in old nodejs root dir
     $self->tag('nodejs-module-installed-in-usr-lib', $file->name)
@@ -150,13 +153,13 @@ sub files {
     # Second regex arg: subpath in /**/nodejs/module/ (eg: node_modules/foo)
     my $subpath = $2;
 
-    my $declared = $self->package;
+    my $declared = $self->processable->name;
     my $processable = $self->processable;
-    my $version = $processable->field('version');
+    my $version = $processable->fields->value('Version');
     $declared .= "( = $version)" if defined $version;
     $version //= '0-1';
     my $provides
-      = Lintian::Relation->and($processable->relation('provides'), $declared);
+      = Lintian::Relation->and($processable->relation('Provides'), $declared);
 
     my $content = $file->bytes;
 
