@@ -1,4 +1,4 @@
-# Copyright © 2019 Felix Lechner
+# Copyright © 2019-2020 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,13 +18,15 @@
 
 package Lintian::Processable::Source;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
+use autodie;
 
 use Carp qw(croak);
 use Path::Tiny;
 
-use Lintian::Util qw(get_dsc_info strip);
+use Lintian::Deb822::File;
 
 use constant EMPTY => q{};
 use constant COLON => q{:};
@@ -33,12 +35,20 @@ use constant SLASH => q{/};
 use Moo;
 use namespace::clean;
 
-with 'Lintian::Collect::Source', 'Lintian::Info::Diffstat',
-  'Lintian::Info::Changelog',
-  'Lintian::Info::Fields::Files', 'Lintian::Info::Orig::Index',
-  'Lintian::Info::Overrides',
-  'Lintian::Info::Package',
-  'Lintian::Processable';
+with 'Lintian::Processable',
+  'Lintian::Processable::Diffstat',
+  'Lintian::Processable::Changelog',
+  'Lintian::Processable::Changelog::Version',
+  'Lintian::Processable::Debian::Control',
+  'Lintian::Processable::Fields::Files',
+  'Lintian::Processable::IsNonFree',
+  'Lintian::Processable::Orig',
+  'Lintian::Processable::Overrides',
+  'Lintian::Processable::Patched',
+  'Lintian::Processable::Source::Diffstat',
+  'Lintian::Processable::Source::Format',
+  'Lintian::Processable::Source::Relation',
+  'Lintian::Processable::Source::Repacked';
 
 =for Pod::Coverage BUILDARGS
 
@@ -56,7 +66,7 @@ Lintian::Processable::Source -- A dsc source package Lintian can process
 =head1 DESCRIPTION
 
 This class represents a 'dsc' file that Lintian can process. Objects
-of this kind are often part of a L<Lintian::Processable::Group>, which
+of this kind are often part of a L<Lintian::Group>, which
 represents all the files in a changes or buildinfo file.
 
 =head1 INSTANCE METHODS
@@ -83,13 +93,14 @@ sub init {
     $self->type('source');
     $self->link_label('dsc');
 
-    my $dinfo = get_dsc_info($self->path)
+    my $primary = Lintian::Deb822::File->new;
+    my @sections = $primary->read_file($self->path)
       or croak $self->path . ' is not valid dsc file';
 
-    $self->verbatim($dinfo);
+    $self->fields($sections[0]);
 
-    my $name = $dinfo->{source} // EMPTY;
-    my $version = $dinfo->{version} // EMPTY;
+    my $name = $self->fields->value('Source') // EMPTY;
+    my $version = $self->fields->value('Version') // EMPTY;
     my $architecture = 'source';
 
     # it is its own source package
@@ -116,6 +127,24 @@ sub init {
     return;
 }
 
+=item unpack
+
+=cut
+
+sub unpack {
+    my ($self) = @_;
+
+    $self->patched->collect($self->groupdir);
+
+    $self->add_diffstat;
+    $self->add_overrides;
+
+    $self->orig->collect($self->groupdir)
+      unless $self->native;
+
+    return;
+}
+
 =back
 
 =head1 AUTHOR
