@@ -1,4 +1,4 @@
-# Copyright © 2019 Felix Lechner
+# Copyright © 2019-2020 Felix Lechner
 #
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -18,8 +18,9 @@
 
 package Lintian::Processable::Udeb;
 
-use strict;
+use v5.20;
 use warnings;
+use utf8;
 
 use Carp qw(croak);
 use Path::Tiny;
@@ -33,19 +34,20 @@ use constant SLASH => q{/};
 use Moo;
 use namespace::clean;
 
-with 'Lintian::Collect::Binary',
+with
+  'Lintian::Processable::Binary::Changelog',
+  'Lintian::Processable::Binary::Class',
+  'Lintian::Processable::Binary::Copyright',
+  'Lintian::Processable::Binary::Relation',
   'Lintian::Processable::Changelog',
-  'Lintian::Processable::Checksums::Md5',
   'Lintian::Processable::Control',
   'Lintian::Processable::Control::Conffiles',
-  'Lintian::Processable::FileInfo',
+  'Lintian::Processable::Installable',
   'Lintian::Processable::Installed',
-  'Lintian::Processable::Java',
+  'Lintian::Processable::IsNonFree',
   'Lintian::Processable::Hardening',
   'Lintian::Processable::Objdump',
   'Lintian::Processable::Overrides',
-  'Lintian::Processable::Scripts',
-  'Lintian::Processable::Scripts::Control',
   'Lintian::Processable';
 
 =for Pod::Coverage BUILDARGS
@@ -92,15 +94,15 @@ sub init {
     $self->type('udeb');
     $self->link_label('deb');
 
-    my $dinfo = get_deb_info($self->path)
+    my $section = get_deb_info($self->path)
       or croak 'could not read control data in ' . $self->path . ": $!";
 
-    $self->verbatim($dinfo);
+    $self->fields($section);
 
-    my $name = $dinfo->{package} // EMPTY;
-    my $version = $dinfo->{version} // EMPTY;
-    my $architecture = $dinfo->{architecture} // EMPTY;
-    my $source = $dinfo->{source} // EMPTY;
+    my $name = $self->fields->value('Package') // EMPTY;
+    my $version = $self->fields->value('Version') // EMPTY;
+    my $architecture = $self->fields->value('Architecture') // EMPTY;
+    my $source = $self->fields->value('Source') // EMPTY;
 
     my $source_version = $version;
 
